==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/nb.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Sirkler",
    "Circles' files" : "Filer tilhørende sirkler",
    "Select circles to filter by" : "Velg sirkler å filtrere etter",
    "No circles found" : "Ingen sirkler funnet",
    "Please select circles to filter by" : "Velg sirkler å filtrere etter",
    "No files found for the selected circles" : "Ingen filer funnet for valgte sirkler",
    "You created the circle {circle}" : "Du opprettet sirkelen {circle}",
    "{author} created the circle {circle}" : "{author} opprettet sirkelen {circle}",
    "You deleted {circle}" : "Du slettet {circle}",
    "{author} deleted {circle}" : "{author} slettet {circle}",
    "You linked {group} to {circle}" : "Du lenket {group} til {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} har blitt lenket til {circle} av {author}",
    "You unlinked {group} from {circle}" : "Du fjernet lenke til {group} fra {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} har fått sin lenke til {circle} fjernet av {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du har endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} endret nivået for lenket gruppe {group} i {circle} til %1$s",
    "You sent a request to link {circle} with {remote}" : "Du sendte en forespørsel om å lenke {circle} med {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendte en forespørsel om å lenke {circle} med {remote}",
    "{remote} requested a link with {circle}" : "{remote} forespurte en lenke med {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Forespørselen om å lenke {circle} med {remote} har blitt avslått",
    "The request to link {remote} with {circle} has been canceled remotely" : "Forespørselen om å lenke {remote} med {circle} har blitt avslått eksternt",
    "The request to link {circle} with {remote} has been accepted" : "Forespørselen om å lenke {circle} med {remote} har blitt godtatt",
    "You dismissed the request to link {remote} with {circle}" : "Du har avslått forespørselen om å lenke {remote} med {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} avslo forespørselen om å lenke {remote} med {circle}",
    "You canceled the request to link {circle} with {remote}" : "Du avbrøt forespørselen om å lenke {circle} med {link}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} avbrøt forespørselen om å lenke {circle} med {remote}",
    "You accepted the request to link {remote} with {circle}" : "Du godtok forespørselen om å lenke {remote} med {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} godtok forespørselen om å lenke {remote} med {circle}",
    "A link between {circle} and {remote} is now up and running" : "En lenke mellom {circle} og {remote} er nå oppe og går",
    "The link between {circle} and {remote} has been shutdown remotely" : "Lenken mellom {circle} og {remote} har blitt fjernet eksternt",
    "You closed the link between {circle} and {remote}" : "Du lukket lenken mellom {circle} og {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} lukket lenken mellom {circle} og {remote}",
    "You joined {circle}" : "Du tok del i {circle}",
    "{member} joined {circle}" : "{member} tok del i {circle}",
    "You accepted the invitation to join {circle}" : "Du godtok invitasjonen om å ta del i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} godtok invitasjonen til å ta del i {circle}",
    "You added {member} as member to {circle}" : "Du la til {member} som medlem i {circle}",
    "You have been added as member to {circle} by {author}" : "Du har blitt lagt til som medlem av {circle} av {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er lagt til som medlem i {circle} av {author}",
    "You added {external} to {circle}" : "Du la {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} har blitt lagt til {circle} av {author}",
    "You accepted {member}'s request to join {circle}" : "Du godtok {member} sin forespørsel om å ta del i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} sin forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "You left {circle}" : "Du forlot {circle}",
    "{member} left {circle}" : "{member} forlot {circle}",
    "You declined the invitation to join {circle}" : "Du avslo invitasjonen til å delta i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} avslo invitasjonen til å delta i {circle}",
    "You cancelled your request to join {circle}" : "Du avbrøt ønsket om å delta i {circle}",
    "{member} cancelled his request to join {circle}" : "{member} avbrøt ønsker om å bli med i {circle}",
    "You removed {member} from {circle}" : "Du fjernet {member} fra {circle}",
    "You have been removed from {circle} by {author}" : "Du ble fjernet fra {circle} av {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ble fjernet fra {circle} av {author}",
    "You removed {external} from {circle}" : "Du fjernet {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} har blitt fjernet fra {circle} av {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du avbrøt {member}s invitasjon til å bli med i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitasjon til å bli med i {circle} ble avbrutt av {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} avbrøt {member}'s invitasjon til å bli med i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du avslo {member}s ønske om å bli med i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ditt ønske om å bli med i {circle} ble avslått av {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s ønske om å bli med i {circle} ble avslått av {author}",
    "You invited {member} to join {circle}" : "Du inviterte {member} til å delta i {circle}",
    "You have been invited to join {circle} by {author}" : "Du har blitt invitert inn i {circle} av {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er invitert inn i {circle} av {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du endret {member}s nivå i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} endret ditt nivå i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} endret {member}s nivå i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte et ønske om å bli med i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
    "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "På hendelser som skjer i en <strong>sirkel</strong> hvor du er medlem",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Ønsker du å bli varslet om hendelser i <strong>sirkler</strong> du modererer?",
    "On global events happening in any <strong>Circle</strong>" : "På global hendelse som skjer i en <strong>sirkel</strong>",
    "Shared to Circles" : "Delt til Sirkler",
    "Single" : "Enkel",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Åpne",
    "Invite" : "Invitere",
    "Join Request" : "Forespørsel om å delta",
    "Friends" : "Venner",
    "Password Protected" : "Passordbeskyttet",
    "No Owner" : "Ingen eier",
    "Hidden" : "Skjult",
    "Local" : "Lokal",
    "Root" : "Rot",
    "Circle Invite" : "Sirkel-invitasjo",
    "Federated" : "Sammenknyttet",
    "Mount point" : "Monteringspunkt",
    "Nextcloud Account" : "Nextcloud-konto",
    "Nextcloud Group" : "Nextcloud-gruppe",
    "Email Address" : "Epostadresse",
    "Contact" : "Kontakt",
    "Circle" : "Sirkel",
    "Nextcloud App" : "Nextcloud-app",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Eier",
    "%s shared »%s« with you." : "%s delte »%s« med deg.",
    "%s shared »%s« with \"%s\"." : "%s delte »%s« med \"%s\".",
    "%s on %s" : "%s på %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte »%2$s« med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delte »%2$s« med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
    "Password to access »%1$s« shared to you by %2$s" : "Passord for tilgang til »%1$s« delt med deg av %2$s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delte flere filer med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Passord for tilgang til filene som ble delt av %1$s",
    "Password to access files" : "Passord for tilgang til filer.",
    "%s shared multiple files with \"%s\"." : "%s delte flere filer med \"%s\".",
    "%s shared multiple files with you." : "%s delte flere filer med deg.",
    "Boot up" : "Start opp",
    "Fresh installation status" : "Status på fersk installasjon",
    "Building Local Database" : "Bygger lokal database",
    "Testing Basic Circle Creation" : "Tester opprettelse av grunnleggende sirkel",
    "Adding local users and moderators" : "Legger til lokale brukere og moderatorer",
    "Circle not found" : "Fant ikke sirkelen",
    "Circle not found " : "Fant ikke sirkelen",
    "This member does not exist" : "Dette medlemmet finnes ikke",
    "This account is already a member of the circle" : "Denne kontoen er allerede medlem av sirkelen",
    "Federated link not found" : "Fant ikke den sammenknyttede lenken",
    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
    "The circle is not federated" : "Sirkelen er ikke sammenknyttet",
    "You cannot join this circle" : "Du kan ikke tilslutte deg denne sirkelen",
    "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
    "Insufficient privileges" : "Utilstrekkelige rettigheter",
    "This member is the owner of the circle" : "Dette medlemmet eier denne sirkelen",
    "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
    "The account is already a member of this circle" : "Denne kontoren er allerede medlem av sirkelen",
    "The account has already been invited into this circle" : "Denne kontoen har allerede blitt invitert til denne sirkelen",
    "%s (Circle owned by %s)" : "%s (Sirkelen eies av %s)",
    "You are now a member of the Circle \"%2$s\"" : "Du er nå medlem av sirkelen \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blitt invitert av %1$s til sirkelen \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendte en forespørsel om å bli medlem av sirkelen \"%2$s\"",
    "Accept" : "Aksepter",
    "Refuse" : "Avvis",
    "Leave the circle" : "Forlat sirkelen",
    "%s" : "%s",
    "Personal Circle" : "Personlig sirkel",
    "%s owned by %s" : "%s eid av %s",
    "You need a specify a type of circle" : "Du må oppgi sirkeltype",
    "A circle with that name exists" : "En sirkel med det navnet finnes",
    "This member is not the owner of the circle" : "Dette medlemmet eier ikke denne sirkelen",
    "This member is not an admin of the circle" : "Dette medlemmet er ikke administrator av sirkelen",
    "Group contains too many members" : "Gruppen inneholder for mange medlemmer",
    "This group does not exist" : "Denne gruppen finnes ikke",
    "This group is already linked to the circle" : "Gruppen er allerede lenket til sirkelen",
    "You cannot edit level in a personal circle" : "Du kan ikke endre nivå i en personlig sirkel",
    "Group cannot be set as owner of a circle" : "Gruppe kan ikke settes som eier av en sirkel",
    "now" : "nå",
    "This account does not exist" : "Denne kontoen finnes ikke",
    "Email format is not valid" : "E-postadressen er ikke gyldig",
    "This contact is not available" : "Denne kontakten er ikke tilgjengelig",
    "You have no permission to create a new circle" : "Du har ikke tilgang til å opprette ny sirkel",
    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
    "%s shared a file with you." : "%s delte en fil med deg.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte innhold med deg.\nDu bør allerede ha mottatt en separat epist med en link for å få tilgang til det.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delte innhold med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
    "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "Initialisation Nextcloud" : "Forbereder Nextcloud",
    "Initialisation Circles App" : "Forbereder Sirkel-app",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kan ikke bruke sirkel-appen før administratoren din har tillat minst én type sirkler",
    "Could not find share" : "Kunne ikke finne ressurs"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/nb.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Lag",
    "You created the team {circle}" : "Du opprettet laget {circle}",
    "{author} created the team {circle}" : "{author} opprettet laget {circle}",
    "You deleted {circle}" : "Du slettet {circle}",
    "{author} deleted {circle}" : "{author} slettet {circle}",
    "You made {member} join {circle}" : "Du fikk {member} til å bli med i {circle}",
    "{author} made {member} join {circle}" : "{author} fikk {member} til å bli med i {circle}",
    "You added team {member} as member to {circle}" : "Du la til lag-{member} som medlem til {circle}",
    "{author} added team {member} as member to {circle}" : "{author} la til lag {member} som medlem til {circle}",
    "You made {member} leave {circle}" : "Du fikk {member} til å forlate {circle}",
    "{author} made {member} leave {circle}" : "{author} fikk {member} til å forlate {circle}",
    "You removed {member} from {circle}" : "Du fjernet {member} fra {circle}",
    "{author} removed {member} from {circle}" : "{author} fjernet {member} fra {circle}",
    "You joined {circle}" : "Du tok del i {circle}",
    "{member} joined {circle}" : "{member} tok del i {circle}",
    "You accepted the invitation to join {circle}" : "Du godtok invitasjonen om å ta del i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} godtok invitasjonen til å ta del i {circle}",
    "You added {member} as member to {circle}" : "Du la til {member} som medlem i {circle}",
    "You have been added as member to {circle} by {author}" : "Du har blitt lagt til som medlem av {circle} av {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er lagt til som medlem i {circle} av {author}",
    "You added {external} to {circle}" : "Du la {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} har blitt lagt til {circle} av {author}",
    "You accepted {member}'s request to join {circle}" : "Du godtok {member} sin forespørsel om å ta del i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} sin forespørsel om å ta del i {circle} har blitt godtatt av {author}",
    "You left {circle}" : "Du forlot {circle}",
    "{member} left {circle}" : "{member} forlot {circle}",
    "You declined the invitation to join {circle}" : "Du avslo invitasjonen til å delta i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} avslo invitasjonen til å delta i {circle}",
    "You cancelled your request to join {circle}" : "Du avbrøt ønsket om å delta i {circle}",
    "{member} cancelled a request to join {circle}" : "{member} kansellerte en forespørsel om å bli med i {circle}",
    "You have been removed from {circle} by {author}" : "Du ble fjernet fra {circle} av {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ble fjernet fra {circle} av {author}",
    "You removed {external} from {circle}" : "Du fjernet {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} har blitt fjernet fra {circle} av {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du avbrøt {member}s invitasjon til å bli med i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitasjon til å bli med i {circle} ble avbrutt av {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} avbrøt {member}'s invitasjon til å bli med i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du avslo {member}s ønske om å bli med i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ditt ønske om å bli med i {circle} ble avslått av {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s ønske om å bli med i {circle} ble avslått av {author}",
    "You invited {member} to join {circle}" : "Du inviterte {member} til å delta i {circle}",
    "You have been invited to join {circle} by {author}" : "Du har blitt invitert inn i {circle} av {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er invitert inn i {circle} av {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du endret {member}s nivå i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} endret ditt nivå i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} endret {member}s nivå i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte et ønske om å bli med i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
    "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "På hendelser som skjer i et <strong>lag</strong> hvor du er medlem",
    "Any important event in a <strong>team</strong> you are moderating" : "Enhver viktig hendelse i et <strong>lag</strong> du modererer",
    "On global events happening in any <strong>team</strong>" : "På globale hendelser som skjer i ethvert <strong>lag</strong>",
    "Single" : "Enkel",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Åpne",
    "Invite" : "Invitere",
    "Join request" : "Forespørsel om å bli med",
    "Friends" : "Venner",
    "Password protected" : "Passordbeskyttet",
    "No Owner" : "Ingen eier",
    "Hidden" : "Skjult",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Rot",
    "Team invite" : "Laginvitasjon",
    "Federated" : "Sammenknyttet",
    "Mount point" : "Monteringspunkt",
    "Nextcloud Account" : "Nextcloud-konto",
    "Nextcloud Group" : "Nextcloud-gruppe",
    "Email address" : "E-post adresse",
    "Contact" : "Kontakt",
    "Circle" : "Sirkel",
    "Nextcloud App" : "Nextcloud-app",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Eier",
    "%s shared »%s« with you." : "%s delte »%s« med deg.",
    "%s shared »%s« with \"%s\"." : "%s delte »%s« med \"%s\".",
    "%s on %s" : "%s på %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte »%2$s« med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delte »%2$s« med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
    "Password to access »%1$s« shared to you by %2$s" : "Passord for tilgang til »%1$s« delt med deg av %2$s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delte flere filer med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Passord for tilgang til filene som ble delt av %1$s",
    "Password to access files" : "Passord for tilgang til filer.",
    "%s shared multiple files with \"%s\"." : "%s delte flere filer med \"%s\".",
    "%s shared multiple files with you." : "%s delte flere filer med deg.",
    "Boot up" : "Start opp",
    "Nextcloud Initialization" : "Nextcloud-initialisering",
    "Circles App Initialization" : "Initialisering av Circles App",
    "Fresh installation status" : "Status på fersk installasjon",
    "Building Local Database" : "Bygger lokal database",
    "Testing Basic Circle Creation" : "Tester opprettelse av grunnleggende sirkel",
    "Adding local users and moderators" : "Legger til lokale brukere og moderatorer",
    "Show all teams" : "Vis alle lag",
    "Create a new team" : "Opprett et nytt lag",
    "Files" : "Filer",
    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
    "The team is not federated" : "Laget er ikke sammenknyttet",
    "You cannot join this team" : "Du kan ikke bli med i dette laget",
    "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
    "Insufficient privileges" : "Utilstrekkelige rettigheter",
    "This member does not exist" : "Dette medlemmet finnes ikke",
    "This member is the owner of the team" : "Medlemmet er eieren av laget",
    "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
    "The account is already a member of this circle" : "Denne kontoren er allerede medlem av sirkelen",
    "The account has already been invited into this circle" : "Denne kontoen har allerede blitt invitert til denne sirkelen",
    "%s (Team owned by %s)" : "%s (Lag eiet av %s)",
    "Accept" : "Aksepter",
    "Refuse" : "Avvis",
    "%s" : "%s",
    "Personal team" : "Personlig lag",
    "%s owned by %s" : "%s eid av %s",
    "You have no permission to create a new team" : "Du har ingen tillatelse til å opprette et nytt lag",
    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
    "%s shared a file with you." : "%s delte en fil med deg.",
    "Open %s" : "Åpne %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte innhold med deg.\nDu bør allerede ha mottatt en separat epist med en link for å få tilgang til det.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delte innhold med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
    "Password to access content shared with you by %1$s" : "Passord for å få tilgang til innhold som deles med deg av %1$s",
    "Password to access content" : "Passord for å få tilgang til innhold",
    "This item is already shared with this team" : "Dette elementet er allerede delt med dette laget",
    "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Lag lar folk lage sine egne grupper av mennesker / kolleger / venner.\nDisse persongruppene kan deretter brukes av en hvilken som helst annen app til delingsformål.",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "Teams' files" : "Lags filer",
    "Select team to filter by" : "Velg lag å filtrere etter",
    "No teams found" : "Ingen lag funnet",
    "Please select teams to filter by" : "Vennligst velg lag å filtrere etter",
    "No files found for the selected teams" : "Ingen filer funnet for valgte lag",
    "Shared to Circles" : "Delt til Sirkler"
},
"nplurals=2; plural=(n != 1);");
